HEX
Server: Apache/2.4.46 (Win64) OpenSSL/1.1.1j PHP/8.4.25
System: Windows NT DESKTOP-4TAV2RJ 10.0 build 19045 (Windows 10) AMD64
User: fred (0)
PHP: 8.4.25
Disabled: NONE
Upload Files
File: C:/Users/fred/anaconda3/Library/bin/h5clear-shared.exe
MZ����@��	�!�L�!This program cannot be run in DOS mode.

$6*��rK��rK��rK��{3�bK�� #��pK�� #��`K�� #��xK�� #��pK��f ��pK���"��wK��rK��"K���"��sK���"��sK��RichrK��PEd�LԀd�"&T@��h`��?p�`��h ;@;0�.text� `.rdataT0@@.datahP8@�.pdata�`<@@.rsrc�p>@@.reloch�@@BH�IH���������H�T$L�D$L�L$ SVWH��0H��H�t$`H������E3�H�t$ L��H��H��;!H��0_^[������������@SH�� ���!��� ����������L��H���H��AH3�H��$�I�[��I�k��I�s�D��I�{�H�����M�s�H��L��M�{؍W
�\!�&!H�
)�o�~!3�f!��!;���L�?L�
?I�֋�w!;���L�=����������$��H�A��(A���I��@�-
A�L@�-A�C@�-�@�:H�� @�-�@H�H��t$�
��xqH�
� H�	��Hc�H�
T>L�U>L�
V>I�֋�� ;��c���H�| Hc;�iH�
�'�� �� H���Z��Z �-�g H���?�B�W H���/3�/ �*�? H��N 3� �I��bH�@H�=@���7 ��?�
�?��?��uV��uR��uN8�?�R���H�
�?�
H��TH�
=H�	�H��H��yCH�
e'�����D�=�?t���u��u��t�H�
'����V�)�=Z?t/L�Q?H��H�'����yH�
&'�H�����=%?t^L�?H��H�'�i��yH�
�&����L��>H��H��&�:��yH�
�&�����vE3�D85�>tHL��>H��H��&����yH�
�&�����;�ͺD���?�	A��L�t$(E3�L��L�t$ ��H���H��H��yH�
\&�V���D85/>tHH�T$8H�����xgH�T$XH��K��xU��$L�L$pH�0&L�D$8H�����D85�=t<H�k;H��:��y(H�
&����fH�
�%����RD85�=tGL�D$PH��H�T$H����yH�
�%����H�|$H�uL9t$Pu
H�
�%�^3�6H��t	H���H�
)=H��t�vH�T$03���|$0L��$�L��$�H��$�H��$�t!L�D$@3�H�T$8��E3�3�3���H�T$@H�L$8�a3�3�GH��VH��%�|$0H��$�H��$�tL�D$@3�H�T$8�4�H�T$@H�L$8���\���U����+r`Wi����@SH�� H�ٹ�,L��H��H�������H��H��������H��H���f������H��H���L������H��H���2������H��H�-�������H��H�c�����sH��H�������YH��H��������?H��H�������%H��H�+�����H��H�q�|������H��H���b������H��H���H������H��H� �.������H��H� �������H��H�������oH��H�������UH��H��������;H��H�������!H��H� �����H��H�
 �x������H��H�C�^������H��H�! �D������H��H�/ �*������H��H���������H��H�K �����kH��H�a H�� [�������H��(M�A8H��I���
�H��(����@SE�H��A��L��A�L��tA�@McP��L�Hc�L#�Ic�J�H�C�HH�C�Dt�D���L�L3�I��[����������������ff�H;
Q8�uH��f�����u��H������@SH�� ����G�����H���'���C��ts�v	H�
�	�B������uR��<��tH�
��f�����������t�N��n��uH�� [ù���H��(��3�H��(�H��(��z��H��(�M���H�\$H�t$WH��0��/���6@2�@�t$ ���؋
�<���#��uJ��<H��H�
��
��t
����H��H�
t�
�}<�@�@�t$ ���l�'H��H�8tH�����tE3�A�P3�H�� �H��H�8tH�����tH��T
�=
H�8�/
H���	
L��H�׋����!��tU@��u�
3ұ���������t;�|$ u��	��H�\$@H�t$HH��0_ù����t���q	����	�H��(�;H��(�r�����@SH�� H��3��H�����H�Ⱥ	�H�� [H�%�H�L$H��8��	��t��)H�
O6�H�D$8H�67H�D$8H��H��6H�7H��5H�D$@H��6�j5	��d5�n5�Hk�H�
f5H��Hk�H�
�4H�L �Hk�H�
�4H�L H�
�����H��8����@SVWH��@H���H���3�E3�H�T$`H��eH��t9H�d$8H�L$hH�T$`L��H�L$0L��H�L$pH�L$(3�H�\$ ���ǃ�|�H��@_^[����H��(���t!eH�%0H�H�H;�t3��H�
�9u�2�H��(ð����@SH�� ��9�ɻDÈ�9���!��u2�����u	3��	���H�� [����@SH��@�=x9���������
��t(��u$H�
Z9���uH�
b9�{��ts2��xH�f3�@�ƒ�?+�H��H��H3�H�D$ H�D$(D$ H�D$0�L$0�8H�D$ H�D$(D$ H�D$0�
�8�L$0�8�
�8��8�H��@[ù�u�H��L���MZf9��uyHc��H���H��9PEu_�f9AuTL+��AH�QH��AH��L��H�$I;�t�JL;�r
�B�L;�rH��(��3�H��u2���z$}2��
��2��2�H������@SH�� ���3҅�t��uH��7H�� [�@SH�� �=�7��t��u���H���A�H�� [��@SH�� H��1H�ً�H3�7��?H��H���u
H�����H��H�
�7��3Ʌ�HD�H��H�� [��H��(���H������H��(��H�\$ UH��H�� H�|1H�2��-�+H;�utH�eH�M�VH�EH�E�P��H1E�L��H�M H1E�D�E H�MH�� H3E H3EH3�H�������H#�H�3��-�+H;�HD�H��0H�\$HH��H��0H�� ]�3��̸��̸@���H�
�6H�%��̰����H��6�H��(��H����H�H��(��3�9�0���H��6�H��6Ã%�6�H�\$UH��$@���H���ٹ�m��t���)�����3�H�M�A���H�M�jH���H���H��E3���
H��t<H�d$8H���H���L��H�L$0L��H���H�L$(H�M�H�L$ 3�H���H�L$PH���3�H���A��H��H����#H���H�D$`�D$P@�D$T�[
��H�D$PH�D$@H�E���H�D$H3��
H�L$@�
��u��u�H���H��$�H��]����;������H��(3��H��t:�MZf9u0HcH<Hȁ9PEu!�f9Au���v
���t��2�H��(���H�
	H�%���H��(H��8csm�u�xu�H ���l�v��@�t3�H��(���H�\$WH�� H��H�=��H�H��t��H��H;�r�H�\$0H�� _�H�\$WH�� H��H�=��H�H��t��H��H;�r�H�\$0H�� _�H�\$H�t$WH��3��.3���-�D��3�D��A��ntelA��GenuD�ҋ�3ɍGE��A��ineI�$Eʉ\$D�ىL$�T$uPH�
�-�%�?�=�t(=`t!=pt������ w$H�H��sD�}3A��D�r3�D�i3�;�|&3���$���\$�L$�T$��	sA��D�:3A��sp�-�-A��sUA��sN3��H�� H�H�T$ H�D$ $<u2��,����,��,@�� t�� ��,��,H�\$(3�H�t$0H��_��3�9�,�����������%�
�%�
�%V�%`�%b�%�%f�%h�%j�%l�%n�%p�%��%t�%f�%�%�
�%�
�%�
�%�
�%j�%�
�%�
�%�
�%�
�%�	����������ff���@UH�� H��H�H�ы�J����H�� ]��@UH��H�3Ɂ8�����]���H2JJJ�I�I�I�I�IxIdIFI*II�H�E�EF&FFhGRGRF�G�G$GG�GFG0FBF�GfF�F�F�F�F�FG�F�E�ExG�FFhEtEDE,EEE~EE�D�D\E�D�D�D�D�C�D�DnDZDDD.D"DDD�C�C�C�Cl!@`&@�@�@�@hVsmzi*helphelheversionversioversiversstatusstatustatstastimageimagimaimfilesizefilesizfilesifilesfilefilfiincrementincremenincremeincremincreincrincinusage: %s [OPTIONS] file_name
  OPTIONS
   -h, --help                Print a usage message and exit
   -V, --version             Print version number and exit
   -s, --status              Clear the status_flags field in the file's superblock
   -m, --image               Remove the metadata cache image from the file
   --filesize                Print the file's EOA and EOF
   --increment=C             Set the file's EOA to the maximum of (EOA, EOF) + C for
                             the file <file_name>.
                             C is >= 0; C is optional and will default to 1M when not set.
                             This option helps to repair a crashed file where the stored EOA
                             in the superblock is different from the actual EOF.
                             The file’s EOA and EOF will be the same after applying
                             this option to the file.

Examples of use:
h5clear -s file_name
  Clear the status_flags field in the superblock of the HDF5 file <file_name>.
h5clear -m file_name
  Remove the metadata cache image from the HDF5 file <file_name>.
h5clear --increment file_name
  Set the EOA to the maximum of (EOA, EOF) + 1M for the file <file_name>.
h5clear --increment=512 file_name
  Set the EOA to the maximum of (EOA, EOF) + 512 for the file <file_name>.
missing file name
h5clearCannot combine --filesize with other options
H5Pcreate
clear_status_flagsH5Pset
skip_eof_checknull_fsm_addrh5tools_fopen
H5Fget_eoa or HDstat
EOA is %I64u; EOF is %I64u 
H5Fset_eoa
H5Fget_mdc_image_info
No cache image in the file
pR@S@LԀd
D@<@((R@�2@�2@P.text$mnP&.text$mn$00b&6.text$x0�.idata$5�2.00cfg�2.CRT$XCA�2.CRT$XCAA�2.CRT$XCZ�2.CRT$XIA�2.CRT$XIAA�2.CRT$XIAC�2.CRT$XIZ3.CRT$XPA3.CRT$XPZ3.CRT$XTA3.CRT$XTZ 3 	.rdata@<H.rdata$zzzdbg�>.rtc$IAA�>.rtc$IZZ�>.rtc$TAA�>.rtc$TZZ�>L.xdata�?�.idata$2�@.idata$3�@�.idata$4�C�.idata$6P`.data`R.bss`�.pdataRp`020
<�!//�%�td
T4���>!td���>!���>0B	d	4Rp�%b&:Lb&2P		brp`0	"�%K��&�Pr0

4	
2P4��P

4
2pd4p8C�D@2�B�E�1xA�E�0�B�G�1�A�G�0�AH�0�A<H�0�B^H�1�A�H�0�A�H�0�A�H�0�@FJ0�H2JJJ�I�I�I�I�IxIdIFI*II�H�E�EF&FFhGRGRF�G�G$GG�GFG0FBF�GfF�F�F�F�F�FG�F�E�ExG�FFhEtEDE,EEE~EE�D�D\E�D�D�D�D�C�D�DnDZDDD.D"DDD�C�C�C�C:h5tools_inith5tools_close1h5tools_error_report2h5tools_fopenget_option}print_versionerror_msg�warn_msg8h5tools_getprognameKh5tools_setprogname9h5tools_getstatusLh5tools_setstatussopt_indqopt_arghdf5_tools.dll�
H5open�
H5check_version*H5Eget_auto28H5Eset_auto2"H5Eauto_is_v2)H5Eget_auto17H5Eset_auto1�H5Fclose�H5Fget_eoa�H5Fincrement_filesize�H5Fget_mdc_image_infoOH5PcloseSH5Pcreate�H5Pset�H5P_CLS_FILE_ACCESS_ID_ghdf5.dll__C_specific_handler>memsetVCRUNTIME140.dll__acrt_iob_func__stdio_common_vfprintffreeUexitPatoi)_strdup_stat64@_seh_filter_exeB_set_app_type	__setusermatherr_configure_narrow_argv3_initialize_narrow_environment(_get_initial_narrow_environment6_initterm7_initterm_e#_exitT_set_fmode__p___argc__p___argv_cexit_c_exit=_register_thread_local_exe_atexit_callback_configthreadlocale_set_new_mode__p__commode4_initialize_onexit_table<_register_onexit_function_crt_atexitgterminateapi-ms-win-crt-stdio-l1-1-0.dllapi-ms-win-crt-heap-l1-1-0.dllapi-ms-win-crt-runtime-l1-1-0.dllapi-ms-win-crt-convert-l1-1-0.dllapi-ms-win-crt-string-l1-1-0.dllapi-ms-win-crt-filesystem-l1-1-0.dllapi-ms-win-crt-math-l1-1-0.dllapi-ms-win-crt-locale-l1-1-0.dll�RtlCaptureContext�RtlLookupFunctionEntry�RtlVirtualUnwind�UnhandledExceptionFilterSetUnhandledExceptionFilter GetCurrentProcess�TerminateProcess�IsProcessorFeaturePresentRQueryPerformanceCounter!GetCurrentProcessId%GetCurrentThreadId�GetSystemTimeAsFileTimeoInitializeSListHead�IsDebuggerPresent�GetModuleHandleWKERNEL32.dll 3@(3@h03@h43@h83@V83@V@3@VH3@VP3@VX3@s`3@sh3@sp3@st3@sx3@m�3@m�3@m�3@m�3@z�3@z�3@z�3@z�3@z�3@z�3@z�3@i�3@i�3@i�3@i�3@i4@i4@i4@i�] �f��2��-�+����/ U�>`w�>���>�v�>v��>�M?P9�><Y$?\�?��0?���>��$?��$?�T4?Tf$?h��>�mt?p�|?�$? i�>lD�?D��?� �> / �>0  �>� � $?� D!�?x!�!$?�!#�?#^#$?p#�#$?�#�#�?�# $�? $�%�?`&b&�?b&�&l?�&�&�?�0�	HXpZ�<assembly xmlns="urn:schemas-microsoft-com:asm.v1" manifestVersion="1.0">
  <trustInfo xmlns="urn:schemas-microsoft-com:asm.v3">
    <security>
      <requestedPrivileges>
        <requestedExecutionLevel level="asInvoker" uiAccess="false"></requestedExecutionLevel>
      </requestedPrivileges>
    </security>
  </trustInfo>
</assembly>PAPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPADDINGPADDINGXXPAD0��������������PL�� �0�@�P�`�p��������������� �0�@�P�`�p��������������